@@ -6,12 +6,13 @@
 # @File    : __init__.py.py
 # @Software: PyCharm
 import nonebot
-from nonebot import on_command, on_request, logger
-from nonebot.adapters.cqhttp import Bot, GroupMessageEvent, GroupRequestEvent, MessageEvent
-from nonebot.adapters.cqhttp.exception import ActionFailed
-from nonebot.adapters.cqhttp.permission import GROUP_ADMIN, GROUP_OWNER, PRIVATE_FRIEND
+from nonebot import  on_command, on_request, logger
+from nonebot.adapters.onebot.v11 import Bot, GroupMessageEvent, GroupRequestEvent, MessageEvent
+from nonebot.adapters.onebot.v11.exception import ActionFailed
+from nonebot.adapters.onebot.v11.permission import GROUP_ADMIN, GROUP_OWNER, PRIVATE_FRIEND
 from nonebot.permission import SUPERUSER
 from nonebot.typing import T_State
+from nonebot.params import State
 import json
 import random
 import re
@@ -29,7 +30,7 @@ admin_init = on_command("群管初始化", priority=1, block=True)
 
 
 @admin_init.handle()
-async def init(bot: Bot, event: MessageEvent, state: T_State):
+async def init(bot: Bot, event: MessageEvent, state: T_State = State()):
     """
     初始化配置文件
     :return:
@@ -71,12 +72,12 @@ def At(data: str):
 
 
 # 查看当前群分管
-gad = on_command('查看分管', aliases={"/gad", "/分群管理"}, priority=1, block=True,
+gad = on_command('分管', aliases={"/gad", "/分群管理"}, priority=1, block=True,
                  permission=GROUP_ADMIN | GROUP_OWNER | SUPERUSER)
 
 
 @gad.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     gid = str(event.group_id)
     admins = await approve.gadmin()
     rely = str(admins[gid])
@@ -88,19 +89,19 @@ su_g_admin = on_command('所有分管', aliases={"/sugad", "/su分群管理"}, p
 
 
 @su_g_admin.handle()
-async def _(bot: Bot, event: MessageEvent, state: T_State):
+async def _(bot: Bot, event: MessageEvent, state: T_State = State()):
     admins = await approve.gadmin()
     admins = str(admins)
     await su_g_admin.send(admins)
 
 
 # 添加分群管理员
-g_admin = on_command('分管+', aliases={"/gad+", "/分群管理+"}, priority=1, block=True,
+g_admin = on_command('分管+', aliases={"/gad+", "分群管理+"}, priority=1, block=True,
                      permission=GROUP_ADMIN | GROUP_OWNER | SUPERUSER)
 
 
 @g_admin.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     msg = str(event.get_message())
     sb = At(event.json())
     gid = str(event.group_id)
@@ -122,11 +123,11 @@ async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
 
 
 # 开启superuser接收处理结果
-su_gad = g_admin = on_command('群管接收', priority=1, block=True, permission=SUPERUSER)
+su_gad = g_admin = on_command('接收', priority=1, block=True, permission=SUPERUSER)
 
 
 @su_gad.handle()
-async def _(bot: Bot, event: MessageEvent, state: T_State):
+async def _(bot: Bot, event: MessageEvent, state: T_State = State()):
     status = await approve.su_on_off()
     if status:
         await su_gad.finish("已开启超管消息接收")
@@ -140,7 +141,7 @@ g_admin_ = on_command('分管-', aliases={"/gad-", "分群管理-"}, priority=1,
 
 
 @g_admin_.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     msg = str(event.get_message())
     sb = At(event.json())
     gid = str(event.group_id)
@@ -170,7 +171,7 @@ super_sp = on_command('所有词条', aliases={"/susp", "/su审批"}, priority=1
 
 
 @super_sp.handle()
-async def _(bot: Bot, event: MessageEvent, state: T_State):
+async def _(bot: Bot, event: MessageEvent, state: T_State = State()):
     answers = await approve.load()
     rely = ""
     for i in answers:
@@ -183,20 +184,20 @@ super_sp_add = on_command('指定词条+', aliases={"/susp+", "/su审批+"}, pri
 
 
 @super_sp_add.handle()
-async def _(bot: Bot, event: MessageEvent, state: T_State):
+async def _(bot: Bot, event: MessageEvent, state: T_State = State()):
     msg = str(event.get_message()).split()
     print(msg)
     logger.info(str(len(msg)), msg)
     if len(msg) == 3:
         gid = msg[1]
-        anwser = msg[2]
-        sp_write = await approve.write(gid, anwser)
+        answer = msg[2]
+        sp_write = await approve.write(gid, answer)
         if gid.isdigit():
             if sp_write:
 
-                await super_sp_add.send(f"群{gid}添加入群审批词条：{anwser}")
+                await super_sp_add.send(f"群{gid}添加入群审批词条：{answer}")
             else:
-                await super_sp_add.send(f'{anwser} 已存在于群{gid}的词条中')
+                await super_sp_add.send(f'{answer} 已存在于群{gid}的词条中')
         else:
             await super_sp_de.finish('输入有误 /susp+ [群号] [词条]')
     else:
@@ -208,7 +209,7 @@ super_sp_de = on_command('指定词条-', aliases={"/susp-", "/su审批-"}, prio
 
 
 @super_sp_de.handle()
-async def _(bot: Bot, event: MessageEvent, state: T_State):
+async def _(bot: Bot, event: MessageEvent, state: T_State = State()):
     msg = str(event.get_message()).split()
     if len(msg) == 3:
         gid = msg[1]
@@ -232,7 +233,7 @@ check = on_command('查看词条', aliases={"/sp", "/审批"}, priority=1, block
 
 
 @check.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     """
     /sp 查看本群词条
     """
@@ -250,7 +251,7 @@ config = on_command('词条+', aliases={'/sp+', '/审批+'}, priority=1, block=T
 
 
 @config.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     """
     /sp+ 增加本群词条
     """
@@ -267,7 +268,7 @@ config_ = on_command('词条-', aliases={'/sp-', '/审批-'}, priority=1, block=
 
 
 @config_.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     """
     /sp- 删除本群某词条
     """
@@ -286,7 +287,7 @@ group_req = on_request(priority=1, block=True)
 
 
 @group_req.handle()
-async def gr_(bot: Bot, event: GroupRequestEvent, state: T_State):
+async def gr_(bot: Bot, event: GroupRequestEvent, state: T_State = State()):
     raw = json.loads(event.json())
     gid = str(event.group_id)
     flag = raw['flag']
@@ -367,7 +368,7 @@ ban = on_command('禁', priority=1, block=True, permission=SUPERUSER)
 
 
 @ban.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     """
     /禁 @user 禁言
     """
@@ -411,7 +412,7 @@ unban = on_command("解", priority=1, block=True, permission=SUPERUSER)
 
 
 @unban.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     """
     /解 @user 解禁
     """
@@ -435,7 +436,7 @@ all = on_command("/all", permission=SUPERUSER, priority=1, block=True)
 
 
 @all.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     """
     （测试时没用..）
     /all 全员禁言
@@ -461,7 +462,7 @@ change = on_command('改', permission=SUPERUSER, priority=1, block=True)
 
 
 @change.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     """
     /改 @user xxx 改群昵称
     """
@@ -489,7 +490,7 @@ title = on_command('头衔', permission=SUPERUSER, priority=1, block=True)
 
 
 @title.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     """
     /头衔 @user  xxx  给某人头衔
     """
@@ -520,7 +521,7 @@ title_ = on_command('删头衔', permission=SUPERUSER, priority=1, block=True)
 
 
 @title_.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     """
     /删头衔 @user 删除头衔
     """
@@ -551,7 +552,7 @@ kick = on_command('踢', permission=SUPERUSER, priority=1, block=True)
 
 
 @kick.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     """
     /踢 @user 踢出某人
     """
@@ -579,7 +580,7 @@ kick_ = on_command('黑', permission=SUPERUSER, priority=1, block=True)
 
 
 @kick_.handle()
-async def _(bot: Bot, event: GroupMessageEvent, state: T_State):
+async def _(bot: Bot, event: GroupMessageEvent, state: T_State = State()):
     """
     /黑 @user 踢出并拉黑某人
     """
